@@ -76,11 +76,12 @@ public:
   static const std::string AN_H;
 
 private:
-  bool IndependentAlleles_;
+  //bool IndependentAlleles_; //jdutheilon 19/09/14: this does not seem to be used anywhere!
 
 public:
   // Constructor and destructor
-  GeneMapperCsvExport(bool ia = false);
+  //GeneMapperCsvExport(bool ia = false);
+  GeneMapperCsvExport() {}
   ~GeneMapperCsvExport();
 
   // public:
